🔖 [Table of Contents](../README.md)

<div align="center">
  <img src="../_images/emoji/brain.png"/>
  <p>
    <sub>
      Corgito Ergo Sum
    </sub>
  </p>
</div>


# Concepts

- [Project](project.md)
- [Runner, Group, and Task](runner-group-and-task.md)
- [Task Lifecycle](task-lifecycle.md)
- [Task Upstream](task-upstream.md)
- [Inputs](inputs.md)
- [Environments](environments.md)
- [Xcom](xcom.md)
- [Template Rendering](template-rendering.md)
- [Specialized Tasks](specialized-tasks/README.md)
  - [DockerComposeTask](specialized-tasks/docker-compose-task.md)
  - [ResourceMaker](specialized-tasks/resource-maker.md)
  - [Notifier](specialized-tasks/notifider.md)
  - [RemoteCmdTask](specialized-tasks/remote-cmd-task.md)
  - [RsyncTask](specialized-tasks/rsync-task.md)
  - [RecurringTask](specialized-tasks/recurring-task.md)
  - [Checker](specialized-tasks/checker.md)
  - [FlowTask](specialized-tasks/flow-task.md)
- [Copying Task](copying-task.md)
- [Extending Task](extending-task.md)
- [Extending CmdTask](extending-cmd-task.md)

🔖 [Table of Contents](../README.md)
